==> hlw-core-0.0.2-20250716.082051-111-sources.jar: cn/gtmap/hlw/core/constant/pzx/SqxxPzxConstant.java <==
package cn.gtmap.hlw.core.constant.pzx;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/7/6 10:07
 * @description SqxxPzxConstant
 */
public class SqxxPzxConstant {

    /**
     * 推送登记配置项 - 可推送登记的slzt
     */
    public static final String SQXX_PUSH_DJ_SLZT = "sqxx.push.dj.slzt";

    /**
     * 推送登记配置项 - 可推送登记的swzt
     */
    public static final String SQXX_PUSH_DJ_SWZT = "sqxx.push.dj.swzt";
    /**
     * 推送登记配置项 - 可推送登记的swzt
     */
    public static final String COUNT_ROLE_COMMON_SQLX = "count.role.common.sqlx";
    /**
     * 推送登记配置项 - 空文件夹是否推送登记
     */
    public static final String SQXX_PUSH_DJ_EMPTY_FOLDER = "sqxx.push.dj.empty.folder";
    /**
     * 推送登记配置项 - 是否保存推送json到本地文件
     */
    public static final String SQXX_PUSH_SAVE_JSON = "sqxx.push.save.json";

    /**
     * 推送登记配置项 - 抵押首次sqlx
     */
    public static final String SQXX_PUSH_DYSC_SQLX = "sqxx.push.dysc.sqlx";

    /**
     * 推送登记配置项 - 抵押首次sqlx
     */
    public static final String SQXX_PUSH_DYZX_SQLX = "sqxx.push.dyzx.sqlx";

    /**
     * 推送登记配置项 - 不需要预审部门配置项
     */
    public static final String SQXX_PUSH_BXYYS_ORGID = "sqxx.push.bxyys.orgid";

    /**
     * 推送登记配置项 - 创建人名称传值
     */
    public static final String SQXX_PUSH_CJRMC = "sqxx.push.cjrmc";

    /**
     * 推送登记配置项 - 分别持证拼接产权证号
     */
    public static final String SQXX_PUSH_FBCZ_PJCQZH = "sqxx.push.fbcz.pjcqzh";
    /**
     * 推送登记配置项 - 推送时权利比例字段加%
     */
    public static final String SQXX_PUSH_ADD_PERCENT = "sqxx.push.add.percent";

    /**
     * 非涉税申请类型
     */
    public static final String SQXX_FSS_SQLX = "sqxx.fss.sqlx";
    /**
     * 不推送受理人申请类型
     */
    public static final String YC_NOPUSH_SLR_SQLX = "yc.noPush.slr.sqlx";
    /**
     * 申请信息推送，附件保存到转移的申请类型
     */
    public static final String SQXX_PUSH_FJXX_BCZY_SQLX = "sqxx.push.fjxx.bczy.sqlx";
}

==> hlw-core-0.0.2-20251024.094938-166-sources.jar: cn/gtmap/hlw/core/constant/pzx/SqxxPzxConstant.java <==
package cn.gtmap.hlw.core.constant.pzx;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/7/6 10:07
 * @description SqxxPzxConstant
 */
public class SqxxPzxConstant {

    /**
     * 推送登记配置项 - 可推送登记的slzt
     */
    public static final String SQXX_PUSH_DJ_SLZT = "sqxx.push.dj.slzt";

    /**
     * 推送登记配置项 - 可推送登记的swzt
     */
    public static final String SQXX_PUSH_DJ_SWZT = "sqxx.push.dj.swzt";
    /**
     * 推送登记配置项 - 可推送登记的swzt
     */
    public static final String COUNT_ROLE_COMMON_SQLX = "count.role.common.sqlx";
    /**
     * 推送登记配置项 - 空文件夹是否推送登记
     */
    public static final String SQXX_PUSH_DJ_EMPTY_FOLDER = "sqxx.push.dj.empty.folder";
    /**
     * 推送登记配置项 - 是否保存推送json到本地文件
     */
    public static final String SQXX_PUSH_SAVE_JSON = "sqxx.push.save.json";

    /**
     * 推送登记配置项 - 抵押首次sqlx
     */
    public static final String SQXX_PUSH_DYSC_SQLX = "sqxx.push.dysc.sqlx";

    /**
     * 推送登记配置项 - 抵押首次sqlx
     */
    public static final String SQXX_PUSH_DYZX_SQLX = "sqxx.push.dyzx.sqlx";

    /**
     * 推送登记配置项 - 不需要预审部门配置项
     */
    public static final String SQXX_PUSH_BXYYS_ORGID = "sqxx.push.bxyys.orgid";

    /**
     * 推送登记配置项 - 创建人名称传值
     */
    public static final String SQXX_PUSH_CJRMC = "sqxx.push.cjrmc";

    /**
     * 推送登记配置项 - 分别持证拼接产权证号
     */
    public static final String SQXX_PUSH_FBCZ_PJCQZH = "sqxx.push.fbcz.pjcqzh";
    /**
     * 推送登记配置项 - 推送时权利比例字段加%
     */
    public static final String SQXX_PUSH_ADD_PERCENT = "sqxx.push.add.percent";
    /**
     * 推送登记配置项 - 组合流程的抵押首次登记原因默认取抵押方式的中文推送登记，放sqlx小类
     */
    public static final String SQXX_PUSH_DJYYBYDYFS_SQLX = "sqxx.push.djyybydyfs.sqlx";

    /**
     * 非涉税申请类型
     */
    public static final String SQXX_FSS_SQLX = "sqxx.fss.sqlx";
    /**
     * 不推送受理人申请类型
     */
    public static final String YC_NOPUSH_SLR_SQLX = "yc.noPush.slr.sqlx";
    /**
     * 申请信息推送，附件保存到转移的申请类型
     */
    public static final String SQXX_PUSH_FJXX_BCZY_SQLX = "sqxx.push.fjxx.bczy.sqlx";
}
